/*std classes*/
#include <vector>
#include <cstdlib> // for getenv() and exit()
#include <signal.h> // for kill()
#include <sys/wait.h> // for waitpid(): see function "void GUI::LaunchScriptRunner()" at the end
#include <csignal> // for signal()
#include <map>
#include <string>


/*itk classes*/
#include "itkImage.h"
#include "itkImageFileReader.h"
#include <itksys/SystemTools.hxx>
#include <itksys/Process.h>
#include <itksys/Configure.h>
#include <AltTBSS.h>
#include <iostream>
#include <fstream>

#include <QFileDialog>
#include <QMessageBox>
#include <QProcess>
#include <QFile>
#include <QTextStream>
#include <QCloseEvent>
#include <QSignalMapper>
#include <QDialog>
#include <QLabel>
#include <QComboBox>
#include <QStackedWidget>
#include <QLineEdit>
#include <QFormLayout>
#include <QDialogButtonBox>
#include <QSignalMapper>
#include <QAction>
#include <QFileInfo>
#include <QCoreApplication>

AltTBSS::AltTBSS(int value) : QDialog()
{
	setupUi(this);

	ReadExistingPrograms();

	QObject::connect(BrowseDTIAtlasBuilder_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_DTIAtlasBuilder()));
	QObject::connect(BrowseImageMath_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_ImageMath()));
	QObject::connect(BrowseCropDTI_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_CropDTI()));
	QObject::connect(Browsedtiprocess_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_dtiprocess()));
	QObject::connect(BrowseBRAINSFit_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_BRAINSFit()));
	QObject::connect(BrowseGreedyAtlas_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_GreedyAtlas()));
	QObject::connect(Browsedtiaverage_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_dtiaverage()));
	QObject::connect(BrowseDTIReg_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_DTIReg()));
	QObject::connect(Browseunu_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_unu()));
	QObject::connect(BrowseMriWatcher_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_MriWatcher()));
	QObject::connect(BrowseResampleDTIlogEuclidean_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_ResampleDTIlogEuclidean()));
	QObject::connect(BrowseResampleDTI_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_ResampleDTI()));
	QObject::connect(BrowseSegPostProcessCLP_QPushButton, SIGNAL(clicked()), this, SLOT(Browse_SegPostProcessCLP()));

	QObject::connect(Done_QPushButton, SIGNAL(clicked()), this, SLOT(WriteSoftwareConfigurationFile()));
}

//Reads in programs to the GUI from the DTIAtlasBuilderSoftConfiguration.txt, which should be one of the save files output by DTIAtlasBuilder. The file
//name should be the first argument when calling this program.
void AltTBSS::ReadExistingPrograms()
{
	//Declare a hash table; we will store program names and their locations from the file outputted by DTIAtlasBuilder
	std::map<std::string,std::string> button_values;

	//Open the file whose name is the first command line argument into this program
	std::ifstream myReadFile;
	myReadFile.open(QCoreApplication::arguments().at(1).toUtf8().constData());

	if (myReadFile.is_open()){
		while (!myReadFile.eof()){

			//Read in a line from the file and split it by where the equal sign (=) is
			std::string output;
			myReadFile >> output;
			std::string key = output.substr(0,output.find("="));
			std::string value = output.substr(output.find("=")+1,output.size());

			//Verify that the read in program is existent
			std::string pathOut;
			std::string commandRan;
			std::vector< std::string > m_FindProgramDTIABExecDirVec;
			std::string DTIABExecutablePath= itksys::SystemTools::GetRealPath( itksys::SystemTools::GetFilenamePath(commandRan).c_str() );
			if(DTIABExecutablePath=="") DTIABExecutablePath= itksys::SystemTools::GetCurrentWorkingDirectory();
				m_FindProgramDTIABExecDirVec.push_back(DTIABExecutablePath);
			value = itksys::SystemTools::FindProgram(value.c_str(), m_FindProgramDTIABExecDirVec);
			std::cout << key + " " + value << std::endl;
			//Insert the program name and its associated location into a hash table
			button_values.insert(std::pair<std::string,std::string>(key,value));
		}
	}
	myReadFile.close();
/*	std::map<std::string, std::string>::iterator button_it;
	for (button_it = button_values.begin(); button_it != button_values.end(); button_it++){
		std::cout << button_it->second << std::endl;
	}
*/
	/*A bit of brute forcing here, but this simply reads values the hash table and sets them in the Qt text boxes*/

	DTIAtlasBuilder_QLineEdit->setText(QString::fromStdString(button_values.at("DTIAtlasBuilder")));
	ImageMath_QLineEdit->setText(QString::fromStdString(button_values.at("ImageMath")));
	ResampleDTIlogEuclidean_QLineEdit->setText(QString::fromStdString(button_values.at("ResampleDTIlogEuclidean")));
	ResampleDTI_QLineEdit->setText(QString::fromStdString(button_values.at("ResampleDTI")));
	CropDTI_QLineEdit->setText(QString::fromStdString(button_values.at("CropDTI")));
	dtiprocess_QLineEdit->setText(QString::fromStdString(button_values.at("dtiprocess")));
	BRAINSFit_QLineEdit->setText(QString::fromStdString(button_values.at("BRAINSFit")));
	GreedyAtlas_QLineEdit->setText(QString::fromStdString(button_values.at("GreedyAtlas")));
	dtiaverage_QLineEdit->setText(QString::fromStdString(button_values.at("dtiaverage")));
	DTIReg_QLineEdit->setText(QString::fromStdString(button_values.at("DTI-Reg")));
	unu_QLineEdit->setText(QString::fromStdString(button_values.at("unu")));
	MriWatcher_QLineEdit->setText(QString::fromStdString(button_values.at("MriWatcher")));
	SegPostProcessCLP_QLineEdit->setText(QString::fromStdString(button_values.at("SegPostProcessCLP")));
}

//Writes the values in the text boxes to a software configuration file for DTIAtlasBuilder
void AltTBSS::WriteSoftwareConfigurationFile(){

	std::ofstream myWriteFile;
	myWriteFile.open(QCoreApplication::arguments().at(1).toUtf8().constData());//QCoreApplication::arguments().at(1).toUtf8().constData()+"xt");
	myWriteFile << "DTIAtlasBuilder="+DTIAtlasBuilder_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "ImageMath="+ImageMath_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "ResampleDTIlogEuclidean="+ResampleDTIlogEuclidean_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "ResampleDTI="+ResampleDTI_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "CropDTI="+CropDTI_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "dtiprocess="+dtiprocess_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "BRAINSFit="+BRAINSFit_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "GreedyAtlas="+GreedyAtlas_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "dtiaverage="+dtiaverage_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "DTI-Reg="+DTIReg_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "unu="+unu_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "MriWatcher="+MriWatcher_QLineEdit->text().toStdString() << std::endl;
	myWriteFile << "SegPostProcessCLP="+SegPostProcessCLP_QLineEdit->text().toStdString() << std::endl;
	myWriteFile.close();
	
	QCoreApplication::quit();
}

void AltTBSS::Browse_ImageMath() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse ImageMath", QString(), "*");
	if(browse.toStdString() != "")
	{
		ImageMath_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_CropDTI() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse CropDTI", QString(),  "*");
	if(browse.toStdString() != "")
	{
		CropDTI_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_dtiprocess() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse dtiprocess", QString(), "*");
	if(browse.toStdString() != "")
	{
		dtiprocess_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_BRAINSFit() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse BRAINSFit", QString(), "*");
	if(browse.toStdString() != "")
	{
		BRAINSFit_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_GreedyAtlas() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse GreedyAtlas", QString(), "*");
	if(browse.toStdString() != "")
	{
		GreedyAtlas_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_dtiaverage() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse dtiaverage", QString(), "*");
	if(browse.toStdString() != "")
	{
		dtiaverage_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_DTIReg() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse DTIReg", QString(), "*");
	if(browse.toStdString() != "")
	{
		DTIReg_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_unu() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse unu", QString(), "*");
	if(browse.toStdString() != "")
	{
		unu_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_MriWatcher() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse MriWatcher", QString(), "*");
	if(browse.toStdString() != "")
	{
		MriWatcher_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_ResampleDTI() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse ResampleDTI", QString(),  "*");
	if(browse.toStdString() != "")
	{
		ResampleDTI_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_ResampleDTIlogEuclidean() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse ResampleDTIlogEuclidean", QString(),  "*");
	if(browse.toStdString() != "")
	{
		ResampleDTIlogEuclidean_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_DTIAtlasBuilder() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse DTIAtlasBuilder", QString(),  "*");
	if(browse.toStdString() != "")
	{
		DTIAtlasBuilder_QLineEdit->setText(browse);
	}

}
void AltTBSS::Browse_SegPostProcessCLP() /*SLOT*/
{
	QString browse=QFileDialog::getOpenFileName(this, "Browse SegPostProcessCLP", QString(),  "*");
	if(browse.toStdString() != "")
	{
		SegPostProcessCLP_QLineEdit->setText(browse);
	}

}
