#!/bin/bash
nogaussian=`echo $@ | grep "\(--nogaussian\|-ng\)"`
help=`echo $@ | grep "\(--help\|-h\)"`
permutations=`echo $@ | grep "\(-n[[:space:]]*[0-9][0-9]*\)" | sed 's/.*-n[[:space:]]*\([0-9]*\)[[:space:]]*.*/\1/g'`
if [ -z "$permutations" ]; then permutations=5000; fi
if [ ! -z "$help" ]
then
	echo "   "
	echo "   $0 [options]"
	echo "   This script generates group files and then prepares data"
	echo "   already projected onto the skeletons for display"
	echo "   Either set a design file in the stats folder with"
	echo "   design_ttest2 before running this. Alternatively, you may"
	echo "   provide a file entitles groupfile.csv in the main folder,"
	echo "   which this script will then convert into the proper"
	echo "   design files. If you run this script without either of"
	echo "   these files, a blank groupfile.csv will be generated,"
	echo "   and you may edit that."
	echo "   Usage:"
	echo "    -h --help : Display this message"
	echo "    -n <integer> : Number of permutations during randomisation"
	echo "                   step (default 5000)"
	echo "    -ng --nogaussian : Do not use gaussian-blurred skeleton"
	echo "   "
	exit
fi

if [ ! -e "stats/design.mat" ]
then
	if [ -e "groupfile.csv" ]
	then
		${FSLDIR}/bin/design_ttest2 stats/design `ls -1 DTI/*.nii.gz | wc -l` 0
		echo "/NumWaves 2" > stats/design.mat
		echo "/NumPoints `cat groupfile.csv | wc -l`" >> stats/design.mat
		echo "/PPheights 1 1" >> stats/design.mat
		echo "/Matrix" >> stats/design.mat
		for i in `cat groupfile.csv`
		do
			num=`echo $i | sed 's/[^,]*,1,/1 0/g' | sed 's/[^,]*,0,/0 1/g'`
			echo $num >> stats/design.mat
		done
	else
		echo "   "
		echo "   Please provide either a design.mat and design.con file in the stats folder"
		echo "   Or write groupfile.csv in the main folder. This script will now generate a"
		echo "   groupfile.csv with all subjects in the same group. If you wish to edit this"
		echo "   file, change the 0's to 1's for the subjects in a different group."
		echo "   "
		ls DTI/*.nii.gz | sed 's/\.nii\.gz/\.nii\.gz,0,/g' > groupfile.csv

		exit
	fi
fi

if [ ! -e "stats/design.con" ]
then
	echo "   "
	echo "   Please provide a design.con file in the stats folder. This, along with design.mat,"
	echo "   is generated by running design_ttest2"
	echo "   "
	exit
fi

stats_contents=`ls stats`
for MEAS in FA AD RD MD
do
	if [ ! -z "$nogaussian" ]
	then
		echo "Randomising ${MEAS} without Gaussian-blurred data"
		if [[ -z  `echo $stats_contents | grep tbss_${MEAS}_nogaussian` ]]
		then
			$FSLDIR/bin/randomise -i stats/all_${MEAS}_skeletonised -o stats/tbss_${MEAS}_nogaussian -m stats/mean_FA_skeleton_mask -d stats/design.mat -t stats/design.con -n $permutations -c 3 -V
		fi
	else
		echo "Ransomising ${MEAS} with Gaussian-blurred data"
		if [[ -z  `echo $stats_contents | grep tbss_${MEAS}` ]]
		then
			$FSLDIR/bin/randomise -i stats/all_${MEAS}_skeletonised -o stats/tbss_${MEAS} -m stats/mean_FA_skeleton_mask -d stats/design.mat -t stats/design.con -n $permutations -c 3 -V
		fi	
	fi
done
#fslview stats/mean_FA stats/mean_FA_skeleton -l Green -b 0.2,0.8 stats/tbss_tstat1 -l Red-Yellow -b 3,6 stats/tbss_tstat2 -l Blue-Lightblue -b 3,6
#fslview stats/mean_FA stats/mean_FA_skeleton -l Green -b 0.2,0.8 stats/tbss_maxc_tstat1 -l Red-Yellow -b 3,6 stats/tbss_maxc_tstat2 -l Blue-Lightblue -b 3,6
#fslview stats/mean_FA stats/mean_FA_skeleton -l Green -b 0.2,0.8 stats/tbss_FA_tstat1 -l Red-Yellow -b 3,6 stats/tbss_FA_tstat2 -l Blue-Lightblue -b 3,6
#fslview stats/mean_FA stats/mean_FA_skeleton -l Green -b 0.2,0.8 stats/tbss_AD_tstat1 -l Red-Yellow -b 3,6 stats/tbss_AD_tstat2 -l Blue-Lightblue -b 3,6
